define([
    'vendor/backbone',
    'lib'
], function(Backbone, ViewCollection) {

    describe('backbone-view-collection', function() {

        var viewCollection;

        it('should correct work add method', function() {

            viewCollection = new ViewCollection();

            viewCollection
                .add(views(3))
                .render();

            expect(viewCollection.el.childNodes.length).to.equal(3);

            viewCollection
                .add(views(1))
                .render();

            expect(viewCollection.el.childNodes.length).to.equal(4);
        });

        it('should correct set resultMethod', function() {

            var ViewCollectionAppend = ViewCollection.extend({

                    resultMethod: 'append'
                }),
                elem = document.createElement('div'),
                child = document.createElement('i');

            elem.appendChild(child);

            viewCollection = new ViewCollectionAppend({

                    el: elem
                }, views(2))
                .render();

            expect(viewCollection.el.contains(child)).to.be.ok();
        });

        it('should correct childNodes length', function() {

            viewCollection = new ViewCollection({}, views(2));

            viewCollection.render();

            expect(viewCollection.el.childNodes.length).to.equal(2);
        });

        it('should correct childNodes length after setChunkSize', function() {

            viewCollection = new ViewCollection({}, views(3));

            viewCollection
                .setChunkSize(2)
                .render();

            expect(viewCollection.el.childNodes.length).to.equal(2);
        });

        it('should correct setting chunk size', function() {

            expect(viewCollection.getChunkSize()).to.equal(2);
        });

        it('should correct length after set next chunk', function() {

            viewCollection
                .nextChunk()
                .render();

            expect(viewCollection.el.childNodes.length).to.equal(3);
        });

        it('should correct childNodes length after clear with saveCurrentChunk', function() {

            viewCollection.clear({

                saveCurrentChunk: true
            });

            expect(viewCollection.el.childNodes.length).to.equal(0);
        });

        it('should correct limit after clear with saveCurrentChunk', function() {

            expect(viewCollection.getLimit()).to.equal(4);
        });

        it('should correct limit after clear without saveCurrentChunk', function() {

            viewCollection.clear();
            expect(viewCollection.getLimit()).to.equal(2);
        });

        it('should correct setCurrentChunk', function() {

            viewCollection.setCurrentChunk(3);
            expect(viewCollection.getLimit()).to.equal(6);
        });

        it('should correct each', function() {

            var _views = views(3),
                i = 0;

            viewCollection = new ViewCollection({}, _views)
                .each(function(view) {

                    expect(view).to.equal(_views[i]);
                    i++;
                });
        });

        function views(num) {

            var result = [];

            for(; result.length < num; result.push(new Backbone.View()));

            return result;
        }
    });
});